<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>CalendarWindow</name>
    <message>
        <location filename="../calendarwindow.cpp" line="203"/>
        <source>First Day of Week</source>
        <translation>Primeiro dia da semana</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="40"/>
        <source>Deepin Calendar</source>
        <translation>Calendário</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Calendar is a date tool.</source>
        <translation>Calendário é uma ferramenta de data.</translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="24"/>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
</context>
</TS>